function PlotLeTalkerWaveforms(r,p,Fs,hwaves,htract);
%Plot some of the waveforms generated by the simulation
%B. Story
%10.25.11

figure(hwaves)
clf

N = length(r.ug);
N2 = round(N/2);

set(gca,'PlotBoxAspectRatio',[1 1 1]);
t = [0:1/Fs:(length(r.ug)-1)/Fs]*1000;


% -------Plot output pressure (audio)-----------
subplot(5,1,1)
plot(t,r.po,'-k','LineWidth',1);
hold
zeroline('-k')

if(max(r.po) > 0 & min(r.po) < 0)
    axis([t(1) t(end) 1.1*min(r.po) 1.1*max(r.po)])
else
    axis([t(1) t(end) -.1 .1])
end;
set(gca,'Box','off','YTick',[0],'FontSize',12,'FontWeight','bold');
v = axis;
text(-.0025*N,(v(3)+v(4))/2,'Po','FontSize',12,'FontWeight','bold')

if(isfield(r,'f0') == 1)
    title(['F0 = ' num2str(r.f0) ' Hz']);
end


% -------Plot subglottal and intraglottal pressure -----------
subplot(5,1,2)

[b,a] = butter(2,30/(44100/2));
hold on
plot(t,r.ps,'-k','LineWidth',1);
plot(t,filtfilt(b,a,r.ps),'-r')
%p_intrag = ((r.f1*p.T*p.L)+(r.f2*p.T*p.L))/2;
p_intrag = (r.f1+r.f2)/2 * 2* p.T*p.L;
plot(t,p_intrag,'-b');
axis([t(1) t(end) min(p_intrag)-1000 max(r.ps)+1000])
zeroline('-k')
set(gca,'Box','off','YTick',[0],'FontSize',12,'FontWeight','bold');
v = axis;
text(-.0025*N,(v(3)+v(4))/2,'Ps & Pg','FontSize',12,'FontWeight','bold')
h = legend('Ps','Ps (smoothed)','Pg');


% -------Plot glottal flow -----------
subplot(5,1,3)
plot(t,r.ug,'-k','LineWidth',1);
axis([t(1) t(end) 0 1.1*max(r.ug)])
hold
zeroline('-k')
set(gca,'Box','off','YTick',[0],'FontSize',12,'FontWeight','bold');
v = axis;
text(-.0025*N,(v(3)+v(4))/2,'Ug','FontSize',12,'FontWeight','bold')
title(['Max Glottal Flow = ' num2str(round(max(r.ug))) ' cm^3/s']);

% -------Plot glottal area -----------
subplot(5,1,4)
plot(t,r.ga,'-k','LineWidth',1);
axis([t(1) t(end) 0 1.1*max(r.ga)])
hold
zeroline('-k')
set(gca,'Box','off','YTick',[0],'FontSize',12,'FontWeight','bold');
v = axis;
text(-.0025*N,(v(3)+v(4))/2,'Ag','FontSize',12,'FontWeight','bold')

title(['Max Glottal Area = ' num2str(round(100*max(r.ga))/100) ' cm^2']);

% 
% -------Plot displacement of lower (x1), upper (x2), and body (xb) masses -----------
subplot(5,1,5)
hold on
plot(t,r.x1,'-b','LineWidth',1);
plot(t,r.x2,'-r','LineWidth',1);
plot(t,r.xb+0.2,'-k','LineWidth',1);
axis([t(1) t(end) -0.1 1.1*max(r.xb)+0.2])
zeroline('-k')
set(gca,'Box','off','YTick',[0],'FontSize',12,'FontWeight','bold');
v = axis;
text(-.0025*N,(v(3)+v(4))/2,'Disp.','FontSize',12,'FontWeight','bold')

xlabel('Time (ms)');
% 

%-===============================
%Open a new figure and plot the trachea and vocal tract area functions

figure(htract)
clf

dx = 0.396825;
x = dx*[1:44]';
clf
hold on
if(p.SUB == 1 && p.SUPRA == 1)
    plot(x,p.ar(1:44),'-b','LineWidth',2);
    x = dx*[1:32];
    x = x-x(end);
    plot(x,p.ar(45:end),'-r','LineWidth',2);
    plot([0 0],[0 10],'-k');
elseif(p.SUB == 1 && p.SUPRA == 0)
    plot(x,0*p.ar(1:44),'-b','LineWidth',2);
    x = dx*[1:32];
    x = x-x(end);
    plot(x,p.ar(45:end),'-r','LineWidth',2);
    plot([0 0],[0 10],'-k');
elseif(p.SUB == 0 && p.SUPRA == 1)
    plot(x,p.ar(1:44),'-b','LineWidth',2);
    x = dx*[1:32];
    x = x-x(end);
    plot(x,0*p.ar(45:end),'-r','LineWidth',2);
    plot([0 0],[0 10],'-k');
else
    plot(x,0*p.ar(1:44),'-b','LineWidth',2);
    x = dx*[1:32];
    x = x-x(end);
    plot(x,0*p.ar(45:end),'-r','LineWidth',2);
    plot([0 0],[0 10],'-k');
end

set(gca,'PlotBoxAspectRatio',[1 .6 1]);
set(gca,'XTick',[-12:2:18]);
set(gca,'FontSize',14,'FontWeight','bold');
xlabel('Distance from glottis (cm)');
ylabel('Area (cm^2)');
axis([-14 18 0 8]);
text(-10,7,'Trachea','FontSize',14);
text(8,7,'Vocal tract','FontSize',14);
grid


function zeroline(lc)

v=axis;
plot([v(1) v(2)],[0 0],lc);

